@@ -200,6 +200,23 @@ class StandardFunction:
         x = param_dict["x"]
         return 1 - np.exp(-(x / lambda_) ** k)
 
+    @staticmethod
+    def ccdf_sigmoid(param_dict):
+        '''
+
+        :param param_dict:
+        :return:
+
+        Logistic function
+        https://en.wikipedia.org/wiki/Logistic_function
+
+        '''
+        k = param_dict["k"]
+        x0 = param_dict["x0"]
+        x = param_dict["x"]
+
+        return 1 / (1 + np.exp(-k*(x-x0)))
+
     @staticmethod
     def cfc(param_dict, units):
         '''
@@ -357,6 +374,7 @@ class StandardFunction:
         time_hist_array = np.asarray(time_history_list)
         return (np.abs(time_hist_array - (float(value) * units.second()))).argmin()
 
+
     @staticmethod
     def object_strain_stress_percentile(param_dict):
         '''
@@ -381,6 +399,7 @@ class StandardFunction:
 
         percentile_values = []
         element_count = 0
+
         for part_id in part_ids:
             index = part_idx[part_id]
             data = part_data[part_id]
@@ -548,6 +567,54 @@ class StandardFunction:
 
         return broken_ribs_prob
 
+
+    @staticmethod
+    def object_stress_strain_elems_max(param_dict):
+        '''
+
+        :param param_dict:
+        :return:
+        '''
+
+        part_ids = param_dict["object_data"]["part_ids"]
+        part_data = param_dict["object_data"]["part_data"]
+        part_idx = param_dict["object_data"]["part_idx"]
+
+        selection_tension_compression = param_dict[PluginsParamDictDef.SELECTION_TENSION_COMPRESSION]
+        integration_point = param_dict[PluginsParamDictDef.INTEGRATION_POINT]
+
+        obj_calc = ObjectCalcUtil()
+        (function_overall_tension_compression, integration_point_function) = \
+            obj_calc.retrieve_functions(selection_tension_compression, integration_point)
+
+        stress_strain_elems_max = []
+
+        for part_id in part_ids:
+            index = part_idx[part_id]
+            data = part_data[part_id]
+            element_ids = np.unique(index[:, 0])
+
+            for i, element_id in enumerate(element_ids):
+                row_ids = np.where(index[:, 0] == element_id)[0]
+                reduced_integration_point_data = integration_point_function(data[:, row_ids, :], axis=1)
+                result_data = function_overall_tension_compression(reduced_integration_point_data, axis=1)
+                stress_strain_elems_max.append(result_data)
+
+        return np.max(np.array(stress_strain_elems_max).T, axis=1)
+
+    @staticmethod
+    def time_from_object(param_dict):
+        '''
+
+        :param param_dict:
+        :return:
+        '''
+
+        return param_dict["object_data"]["time"]
+
+
+
+
     @staticmethod
     def csdm(param_dict):
         '''
