@@ -207,6 +207,7 @@ class EloutObject(BinoutData):
         '''
 
         strain_stress_idx = EloutIndex.translate_strain_stress(json_object["strain_stress"])
+
         part_ids = self.get_part_ids_by_object_name(json_object["ID"], strain_stress_idx)
         element_count = 0
 
@@ -216,10 +217,12 @@ class EloutObject(BinoutData):
                 data_delta_t = delta_t
 
         time_step_indices = list(range(data_offset, data_delta_t))
+
         part_data = {}
         part_index = {}
 
         assert(len(part_ids) > 0)
+
         for part_id in part_ids:
             index, data = self.get_part_data(strain_stress_idx, part_id, time_step_indices=time_step_indices)
             part_data[part_id] = data
@@ -236,7 +239,8 @@ class EloutObject(BinoutData):
         return {"part_ids": part_ids, "part_data": part_data,
                 "part_idx": part_index, "time_step_indices": time_step_indices,
                 "element_type" : element_type, "part_value": part_volume,
-                "el_by_part_id_el_id": el_by_part_id_el_id}
+                "el_by_part_id_el_id": el_by_part_id_el_id,
+                "time": self.get_interpolated_time()[time_step_indices]}
 
     def _read_volume_data_from_file_volume(self, path_to_volume):
         '''
