@@ -8,7 +8,7 @@ from ..utils.constants import DefinitionConstants, OutputStringForPlugins, Plugi
 
 class CriteriaController(Plugin, PluginInterface):
     def __init__(self, calculation_procedure_def_file, object_def_file, data_source, user_function_object=None,
-                 volume_def_file=None, code_type="BINOUT"):
+                 volume_def_file=None, code_type="LS-DYNA"):
         '''
         Initialization i.e. call Plugin constructor
         :param: root
