@@ -139,12 +139,18 @@ class Plugin(object):
                 return StandardFunction.central_differences(param_dict)
             elif function_name == StandardFunctionsDefinition.UNIVERSAL:
                 return StandardFunction.object_strain_stress_hist(param_dict)
+            elif function_name == StandardFunctionsDefinition.STRESS_STRAIN_MAX:
+                return StandardFunction.object_stress_strain_elems_max(param_dict)
             elif function_name == StandardFunctionsDefinition.PERCENTILE:
                 return StandardFunction.object_strain_stress_percentile(param_dict)
+            elif function_name == StandardFunctionsDefinition.SIGMOID:
+                return StandardFunction.ccdf_sigmoid(param_dict)
             elif function_name == StandardFunctionsDefinition.LINSPACE:
                 return StandardFunction.linspace(param_dict)
             elif function_name == StandardFunctionsDefinition.FORMAN_RIB_CRITERIA:
                 return StandardFunction.forman_criteria(param_dict)
+            elif function_name == StandardFunctionsDefinition.OBJECT_TIME:
+                return StandardFunction.time_from_object(param_dict)
             elif function_name == StandardFunctionsDefinition.CCDF_WEIBULL:
                 return StandardFunction.ccdf_weibull(param_dict)
             elif function_name == StandardFunctionsDefinition.AT_INDEX:
