@@ -250,7 +250,11 @@ class StandardFunctionsDefinition:
     RES_ACC_from_XYZ_Velocities = "RES_ACC_from_XYZ_Velocities"
     central_differences = "central_differences"
     UNIVERSAL = "universal"
+    STRESS_STRAIN_MAX = "stress_strain_max"
+    OBJECT_TIME = "object_time"
+
     PERCENTILE = "percentile"
+    SIGMOID = "sigmoid"
     CSDM = "csdm"
     FORMAN_RIB_CRITERIA = "forman_rib_criteria"
     CCDF_WEIBULL = "ccdf_weibull"
